@@ -21,13 +21,12 @@ from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
 from .utils import set_session_key, check_user_can_login, invalidate_cookie
-from .exceptions import UnsubscribedUserException, DjangoStaffUsersCanNotLoginException, ProfileIncompleteException  #, DectivatedUserException
+from .exceptions import UnsubscribedUserException, DjangoStaffUsersCanNotLoginException  # , ProfileIncompleteException, DectivatedUserException
 from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
 from .apps.services.models import Subscription
 from .apps.profiles.utils import get_or_create_user_profile, update_profile
-from .apps.profiles.models import Profile
 from .apps.passepartout.utils import get_passepartout_login_redirect_url
 from .tokens.utils import get_request_jwt_fingerprint, get_request_jwt, renew_response_jwt
 from .permissions import is_authenticated, is_staff, is_django_staff
@@ -214,36 +213,19 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         if authentication_success:
             if is_authenticated(user):
                 logger.info('adapter authenticated "{}"'.format(user))
-                _profile = get_or_create_user_profile(user, Profile)
+                _profile = get_or_create_user_profile(user)
 
                 return user
         else:
             self.authentication_failed(request, **credentials)
 
-    def update_user_profile(self, user, cleaned_data, commit=True):
-        logger.debug('adapter update user profile')
-        profile = update_profile(user.sso_app_profile, cleaned_data, commit)
-
-        return profile
-
     @transaction.atomic
     def save_user(self, request, user, form, commit=True):
         """
         Saves a new User instance using information provided in the
         signup form.
         """
-        # !atomic
-        cleaned_data = form.cleaned_data
-        email = cleaned_data.get('email', None)
-        username = cleaned_data.get('username', None)
-        logger.debug('Saving new user {0} with email {1}.'.format(
-                     username, email))
-
-        new_user = super(AccountAdapter, self).save_user(request, user, form, commit)
-
-        self.update_user_profile(new_user, cleaned_data, commit)
-
-        return new_user
+        return super(AccountAdapter, self).save_user(request, user, form, commit)
 
     def render_mail(self, template_prefix, email, context):
         user = context.get('user')
