@@ -336,6 +336,10 @@ class AppSettings(object):
     def USER_TYPES(self):
         return self._setting('USER_TYPES', [], list)
 
+    @property
+    def DEFAULT_USER_GROUPS(self):
+        return self._setting('DEFAULT_USER_GROUPS', [], list)
+
     @property
     def SAME_SITE_COOKIE_NONE(self):
         return self._setting('SAME_SITE_COOKIE_NONE', False, bool)
