@@ -2,10 +2,12 @@ import logging
 
 from django.db.models.signals import m2m_changed, post_save
 from django.dispatch import receiver
+from django.contrib.auth.signals import user_logged_in
 
 from .... import app_settings
 from ....permissions import is_django_staff
 from ...profiles.models import Profile
+from ...users.utils import add_user_to_default_groups
 from ..models import Group
 
 logger = logging.getLogger('django_sso_app.core.apps.groups.signals')
@@ -66,6 +68,8 @@ def user_profile_updated(sender, instance, created, **kwargs):
         return
 
     if not is_django_staff(user):
+        add_user_to_default_groups(user)
+
         should_manage_groups = app_settings.BACKEND_ENABLED or app_settings.REPLICATE_PROFILE
 
         if should_manage_groups:
@@ -100,3 +104,14 @@ def user_profile_updated(sender, instance, created, **kwargs):
 
                     if profile.groups.filter(name=group.name).count() == 0:
                         profile.groups.add(group)
+
+
+@receiver(user_logged_in)
+def post_user_login(**kwargs):
+    """
+    Check if user belongs to all DEFAULT_USER_GROUPS, if not
+    """
+    user = kwargs['user']
+
+    if not is_django_staff(user):
+        add_user_to_default_groups(user)
