@@ -5,7 +5,6 @@ from django.db.models.signals import post_save
 from django.contrib.auth import get_user_model
 
 from ..utils import get_or_create_user_profile
-from ..models import Profile
 
 logger = logging.getLogger('django_sso_app.core.apps.profiles.signals')
 
@@ -23,7 +22,7 @@ def create_user_profile(sender, instance, created, **kwargs):
     if created:
         logger.debug('user created, creating profile')
 
-        profile = get_or_create_user_profile(user, Profile, commit=True)
+        profile = get_or_create_user_profile(user, commit=True)
 
         logger.debug('new profile created "{}"'.format(profile))
 
