@@ -3,12 +3,9 @@ import logging
 # import pyximport
 # pyximport.install()
 
-from django.contrib.auth import get_user_model
-
 from ...permissions import is_django_staff
 from ... import app_settings
-
-User = get_user_model()
+from .models import Profile as Profile
 
 logger = logging.getLogger('django_sso_app.core.apps.profiles')
 
@@ -29,16 +26,16 @@ def update_profile(profile, update_object, commit=True):
     return profile
 
 
-def get_or_create_user_profile(user, ProfileModel, initials=None, commit=True):
+def get_or_create_user_profile(user, initials=None, commit=True):
     logger.debug('get or create user profile')
 
     try:
         profile = user.sso_app_profile
 
-    except ProfileModel.DoesNotExist:
+    except Profile.DoesNotExist:
         logger.info('User "{}" has no profile, creating one'.format(user))
 
-        profile = ProfileModel(user=user, django_user_email=user.email, django_user_username=user.username)
+        profile = Profile(user=user, django_user_email=user.email, django_user_username=user.username)
 
         sso_id = getattr(user, '__dssoa__profile__sso_id', None)
         if sso_id is not None:
