@@ -5,8 +5,6 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth.hashers import get_hasher, identify_hasher
 
-# from ... import app_settings
-
 logger = logging.getLogger('django_sso_app.core.apps.users')
 
 
@@ -85,6 +83,12 @@ class DjangoSsoAppUserModelMixin(object):
         setattr(self, '__dssoa__old_username', self.username)
         # setattr(self, '__serialized_as_string', self.serialized_as_string)  # replaced by '..__user_loggin_in'
 
+    def save(self, *args, **kwargs):
+        # pre save
+        super(DjangoSsoAppUserModelMixin, self).save(*args, **kwargs)
+        # post save
+        #setattr(new_user, 'sso_app_profile', get_or_create_user_profile(new_user, commit=True))
+
     def get_absolute_rest_url(self):
         profile = self.get_sso_app_profile()
         if profile is not None:
