@@ -110,16 +110,6 @@ def check_user_can_login(user, skip_profile_checks=False):
                         raise ProfileIncompleteException(app_settings.PROFILE_COMPLETE_URL)
 
 
-def is_test_user(user):
-    """
-    Chack if user is TEST_USER
-    :param user:
-    :return:
-    """
-
-    return user.username == app_settings.TEST_USER_USERNAME or user.email == app_settings.TEST_USER_EMAIL
-
-
 def get_random_token(length=4):
     """
     Returns random token
